@@ -17,7 +17,7 @@ if [[ "$TEST" = false ]]; then
 		echo "command $cmd excute........"
 		./gradlew $cmd --stacktrace --info
 
-		cp -rf ${projectDir}/app/build/outputs/apk/global/debug ${outputs}
+		cp -rf ${projectDir}/app/build/outputs ${outputs}
 	    echo "fetch your apk in $outputs"
 	fi
 fi
\ No newline at end of file
